@@ -21,10 +21,11 @@ class SqlConnection(object):
             SqlConnection.pool[self.db_name] =  PooledDB(creator=mysql, mincached=1 , maxcached=20 ,
                                                          host=self.host , port=self.port, user=self.user,
                                                          passwd=self.passwd, db=self.db_name,
-                                                         use_unicode=T,charset="utf8")
+                                                         use_unicode=True,charset="utf8")
         return SqlConnection.pool[self.db_name].connection()
 
     def __del__(self):
+        print("SqlConnection del")
         self.cursor.close()
         self.conn.close()
 
